pub struct Gates {
pub path_matches: Vec<String>,
pub path_not_matches: Vec<String>,
pub file_contains: Vec<String>,
pub file_not_contains: Vec<String>,
}Expand description
The gates a rule declares, as written in config.
Fields
path_matches: Vec<String>Only files matching one of these are considered.
path_not_matches: Vec<String>Files matching any of these are skipped.
file_contains: Vec<String>Only files whose bytes contain all of these are parsed.
file_not_contains: Vec<String>Files whose bytes contain any of these are skipped.
Implementations